@@ -6,7 +6,8 @@ from pydantic import BaseModel as PdModel
 from sanic import json
 from sanic.exceptions import NotFound
 
-from web_foundation.app.infrastructure.database.middleware import AccessDMW, AccessProtectIdentity  # type: ignore
+from web_foundation.app.infrastructure.database.middleware import AccessDMW, AccessProtectIdentity, \
+    EntityId  # type: ignore
 from web_foundation.app.infrastructure.database.models import AbstractDbModel, GenericDbType
 from web_foundation.app.service.service import Service
 from web_foundation.workers.web.sanic_ext.pipline_ext import set_to_pipline, Protector, Pipeline, mark_pipelined
@@ -104,7 +105,8 @@ class AccessService(Service):
         match inc.request.method:
             case HTTPMethod.GET.value:
                 kwargs = inc.r_kwargs
-                if prot.entity_id is None:
+                entity_id = kwargs.get("entity_id")
+                if entity_id is None:
                     limit = inc.request.args.get("limit")
                     offset = inc.request.args.get("offset")
                     limit = int(limit) if limit and limit.isdigit() else 100
@@ -129,7 +131,7 @@ class AccessService(Service):
                     retrieved_all, total = await access_middleware.read_all(model, prot, limit, offset, **kwargs)
                     res = [await model.values_dict() for model in retrieved_all]
                     return res
-                retrieved = await access_middleware.read(model, prot, **kwargs)
+                retrieved = await access_middleware.read(model, entity_id, prot, **kwargs)
                 if retrieved:
                     result = await retrieved.values_dict()
                     return result
@@ -145,9 +147,13 @@ class AccessService(Service):
 
             case HTTPMethod.PATCH.value:
                 assert inc.dto
-                retrieved = await access_middleware.update(model, prot, inc.dto, **inc.r_kwargs)
+                entity_id = inc.r_kwargs.get("entity_id")
+                assert entity_id
+                retrieved = await access_middleware.update(model, entity_id, prot, inc.dto, **inc.r_kwargs)
                 return json(await retrieved.values_dict())
 
             case HTTPMethod.DELETE.value:
-                retrieved = await access_middleware.delete(model, prot, **inc.r_kwargs)
+                entity_id = inc.r_kwargs.get("entity_id")
+                assert entity_id
+                retrieved = await access_middleware.delete(model, entity_id, prot, **inc.r_kwargs)
                 return json(await retrieved.values_dict())
