@@ -1,10 +1,10 @@
 import asyncio
-from typing import Coroutine, Callable
+from typing import Coroutine, Callable, TypeVar
 
 from aioprocessing import AioQueue, AioEvent, AioLock
 from loguru import logger
 
-from web_foundation.kernel.isolates.pipes import IsolatePipes, IMessage
+from web_foundation.kernel.isolates.pipes import IsolatePipes, IMessage, GenericIMessage
 
 
 class IChannel:
@@ -12,6 +12,8 @@ class IChannel:
     pipes: IsolatePipes
     name: str
     debug: bool
+    consume_pipe: IsolatePipes
+    produce_pipe: IsolatePipes
 
     def __init__(self, wroker_name: str, debug: bool = False):
         self.name = wroker_name
@@ -27,17 +29,17 @@ class IChannel:
         logger.warning(msg)
         await self.produce_pipe.write(msg)
 
-    async def _listen(self, pipe: IsolatePipes, callback: Callable[[IMessage], Coroutine]):
+    async def _listen(self, pipe: IsolatePipes, callback: Callable[[GenericIMessage], Coroutine]):
         while True:
             if pipe.empty():
                 await asyncio.sleep(self.read_timeout)
-            r: IMessage = await pipe.read()
+            r: GenericIMessage = await pipe.read()
             if self.debug:
                 logger.info(f"Channel {self.name} {'send' if pipe == self.produce_pipe else 'receive'} message: {r}")
             await callback(r)
 
-    async def listen_produce(self, callback: Callable[[IMessage], Coroutine]):
+    async def listen_produce(self, callback: Callable[[GenericIMessage], Coroutine]):
         await self._listen(self.produce_pipe, callback)
 
-    async def listen_consume(self, callback: Callable[[IMessage], Coroutine]):
+    async def listen_consume(self, callback: Callable[[GenericIMessage], Coroutine]):
         await self._listen(self.consume_pipe, callback)
