@@ -1,10 +1,12 @@
 import asyncio
-from asyncio import Future
+from asyncio import Task
 from typing import Dict, List
+
+from loguru import logger
+
 from web_foundation.kernel import Isolate
 from web_foundation.kernel.isolates.channel import IChannel
-from web_foundation.kernel.isolates.pipes import IMessage
-from loguru import logger
+from web_foundation.kernel.isolates.pipes import GenericIMessage
 
 
 class IDistributor:
@@ -15,15 +17,16 @@ class IDistributor:
         for iso in isolates:
             self.channels.update({iso.name: iso.channel})
 
-    async def on_channel_sent(self, msg: IMessage):
+    async def on_channel_sent(self, msg: GenericIMessage):
         logger.warning(msg)
-        await self.channels.get(msg.destination).consume_pipe.write(msg)
+        channel: IChannel = self.channels[msg.destination]
+        await channel.consume_pipe.write(msg)
 
-    def preform(self) -> List[Future]:
+    def preform(self) -> List[Task]:
         tasks = []
         for channel in self.channels.values():
             tasks.append(asyncio.ensure_future(
                 channel.listen_produce(
                     self.on_channel_sent
                 )))
-        return tasks
\ No newline at end of file
+        return tasks
