@@ -3,6 +3,7 @@ import os
 import pathlib
 import warnings
 from signal import signal as signal_func, SIGINT, SIGTERM, Signals
+from typing import List
 
 from loguru import logger
 from pydantic import BaseModel as PDModel
@@ -13,7 +14,7 @@ from web_foundation.app import AccessService, AccessSpec
 from web_foundation.app import Service
 from web_foundation.app.infrastructure.database.initiator import DbConfig
 from web_foundation.kernel import IDistributor
-from web_foundation.workers import TaskIMessage, TaskExecutor
+from web_foundation.workers import TaskIMessage, TaskExecutor, PipelinedRouteConf
 from web_foundation.workers import ServerConfig, WebServer
 from web_foundation.workers import set_to_pipline, Pipeline, mark_pipelined, Protector
 from web_foundation.workers import HTTPMethod, ProtectIdentity, InputContext
@@ -31,11 +32,11 @@ class AppBaseService(Service):
 
 
 class AnyAppPipeline(Pipeline):
-    routes_confs = []
+    routes_confs: List[PipelinedRouteConf] = []
 
 
 class AnyAppAccessPipline(Pipeline):
-    routes_confs = []
+    routes_confs: List[PipelinedRouteConf] = []
 
 
 @mark_pipelined(AnyAppPipeline)
@@ -104,12 +105,11 @@ async def main():
     web_server = WebServer(app.config.server)
     web_server.configure(f"{app.name}_sanic_{1}", app.ctx, sock)
     task = TaskExecutor()
-    task.configure(f"{app.name}_task_executor")
+    task.configure(f"{app.name}_task_executor", "something")
     web_server.add_pipelines(AnyAppPipeline)
     web_server.add_pipelines(AnyAppAccessPipline)
     app.add_isolate(web_server)
     app.add_isolate(task)
-
     distrib = IDistributor(app.isolates)
 
     def sig_handler(signal, frame):
@@ -121,7 +121,6 @@ async def main():
     signal_func(SIGINT, lambda s, f: sig_handler(s, f))
     signal_func(SIGTERM, lambda s, f: sig_handler(s, f))
 
-    print(distrib.channels)
     await asyncio.wait(app.perform() + distrib.preform())
 
     # sock.close()
