@@ -1,5 +1,6 @@
 import asyncio
 from asyncio import Task
+from functools import singledispatchmethod
 
 from web_foundation.workers.background.message import TaskIMessage, TaskReplyIMessage
 from web_foundation.workers.worker import Worker
@@ -10,7 +11,12 @@ class TaskExecutor(Worker):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
-    def _configure(self, *args, **kwargs):
+    @singledispatchmethod
+    def _configure(self, name: str, *args, **kwargs):
+        pass
+
+    @_configure.register
+    def _(self, something:str):
         pass
 
     async def _run(self):
@@ -27,5 +33,5 @@ class TaskExecutor(Worker):
     def produce_response(self, resp: Task):
         asyncio.create_task(self.channel.produce(resp.result()))
 
-    def _close(self,*args,**kwargs):
+    def _close(self, *args, **kwargs):
         pass
