@@ -2,8 +2,8 @@ from web_foundation.kernel import Isolate
 
 
 class ScheduledExecutor(Isolate):
-    def sync_run(self):
+    def _close(self):
         pass
 
-    async def async_run(self):
+    async def _run(self):
         pass
