@@ -1,8 +1,8 @@
 import asyncio
 import os
 import socket
-from typing import List, Type
-
+from typing import List, Type, Any
+from functools import singledispatchmethod
 from pydantic import BaseModel as PDModel
 from sanic import Sanic
 from sanic.server.socket import bind_socket
@@ -31,7 +31,12 @@ class WebServer(Worker):
         super().__init__(*args, **kwargs)
         self.config = config
 
-    def _configure(self, ctx: NamedContext, sock: socket.socket = None):
+    @singledispatchmethod
+    def _configure(self, *args, **kwargs):
+        pass
+
+    @_configure.register
+    def _(self, ctx: NamedContext, sock: socket.socket = None):
         self.socket = sock if sock else self.create_socket(self.config)
         self.sanic_app = Sanic(self.name)
         self.sanic_app.after_server_stop(self.close)
@@ -59,7 +64,7 @@ class WebServer(Worker):
         except KeyboardInterrupt:
             self._close()
 
-    def _close(self,*args,**kwargs):
+    def _close(self, *args, **kwargs):
         self.socket.close()
 
     @staticmethod
